export interface Comment {
  id: number
  circleId: number
  userId: number
  userName: string
  userAvatar: string
  reviewContent: string
  upvoteCount: any
  replayReviewId: any
  reviewTime: number
  createTime: number
  replayToUserName: any
  replayToUserId: any
  replayFirstId: any
  upvote: boolean
  ownDel: boolean
}
export interface Task {
  id: number
  taskKey: string
  taskValue: string
  createTime: string
  sort: number
  status: number
}
export interface MaterialDealer {
  id: number
  logoUrl: string
  materialsName: string
  materialsType: number
  brandLevel: number
  manageType: number
  manageBrand: number
  brandType: number
  storeAddress: string
  storeName: string
  contactPerson: string
  contactPhone: string
  invoiceTitle: string
  taxpayerNumber: string
  invoiceAddr: string
  bankDeposit: string
  agreementFileUrl: string
  virtualArrival: number
  status: string
  createTime: string
  points: number
  clockPoints: string
  orderCount: number
  pointsExchangeRate: number
  shopList: ShopList[]
  /**
   * 累计到店次数
   */
  cumulativeStoreNum?: number
}
export interface ShopList {
  id: number
  materialsId: number
  shopAddr: string
  shopName: string
  shopContactPerson: string
  shopContactPhone: string

  longitude: number
  latitude: number
  radius: number
}
export interface MaterialsList {
  id: number
  logoUrl: string
  materialsName: string
  materialsType: number
  brandLevel: number
  manageType: number
  manageBrand: number
  brandType: number
  invoiceTitle: string
  taxpayerNumber: string
  invoiceAddr: string
  bankDeposit: string
  virtualArrival: number
  status: string
  points: number
  shopList: ShopList[]
  clockCount: number
}
export interface MaterialDealerRes {
  brandLevel: number
  brandLevelName: string
  pointsRate: number
  materialsList: MaterialsList[]
}
export interface FodderList {
  createTime: number
  updateTime: number
  creator: string
  updater: string
  deleted: boolean
  id: number
  materialsId: number
  fodderUrl: string
}
export interface ProductDolist {
  createTime: number
  updateTime: number
  creator: string
  updater: string
  deleted: boolean
  id: number
  materialsId: number
  productTitleId: any
  productTitleName: string
  productImgUrl: string
}
export interface MaterialDealerHomePage {
  materialsId: any
  bannerUrl: string
  brandAdvantageUrl: string
  brandAdvantageDesc: string
  fodderList: FodderList[]
  productDOList: ProductDolist[]
}
export interface Content {
  id: number
  /**
   * 内容类型 - 0: 设计游学
   */
  contentType: string
  /**
   * 内容类型名称
   */
  contentTypeName: string
  /**
   * 内容分类
   */
  contentCategory: string
  /**
   * 内容分类名称
   */
  contentCategoryName: string
  /**
   * 内容标题
   */
  title: string
  /**
   * 班级
   */
  classGrade: string
  /**
   * 游学开始时间
   */
  studyStartDate: string
  /**
   * 游学结束时间
   */
  studyEndDate: string
  /**
   * 游学人数
   */
  studyPersonCount: number
  /**
   * 领队
   */
  studyLeader: string
  /**
   * 班长
   */
  studyMonitor: string
  bannerUrl: string
  /**
   * 内容详情
   */
  contentDetail: string
  /**
   * 期数
   */
  periodsCount: number
  /**
   * 活动，举办开始时间
   */
  hostDate: string
  /**
   * 举办方
   */
  activityHost: string
  /**
   * 赞助品牌
   */
  supportBrand: string
  /**
   * 状态 - 0: 正常, 1: 停用
   */
  status: number
  viewsCount: number
  viewCount30Day: number
  createTime: string
}
export interface Category {
  id: number
  name: string
  code: string
  sort: number
  parentId: any
  level: number
  children?: Category[]
}
/**
 * 活动日程
 */
export interface Schedule {
  createTime: number
  updateTime: number
  creator: string
  updater: string
  deleted: boolean
  id: number
  studyId: number
  travelDate: number
  travelTime: number
  title: string
  travelDesc: string
  clockExplainDesc: string
  clockExplainUrl: string
}
/**
 * 线下活动
 */
export interface Activity {
  id: number
  name: string
  activityType: string
  /**
   * 报名开始时间 or 计划报名时间
   */
  applyStartTime: string
  planApplyStartTime?: string
  studyStartTime: string
  studyEndTime: string
  /**
   * 报名结束时间 or 计划报名截止时间
   */
  applyEndTime: string
  planApplyEndTime?: string
  /**
   * 报名状态 or 计划游学名额开关
   */
  applyStatus: string
  /**
   * 计划报名人员 or 计划游学名额
   */
  applyNumber: string
  /**
   * 游学年度
   */
  studyYear: string
  /**
   * 活动开始时间
   */
  activityStartTime: string
  /**
   * 活动结束时间
   */
  activityEndTime: string
  /**
   * 活动名额（限制，不限制）
   */
  activityAllowType: string
  /**
   * 活动名额大小
   */
  activityAllowCount: number
  /**
   * 活动地点
   */
  activityAddr: string
  /**
   * 是否需要积分（需要，不需要）
   */
  needPointsType: string
  /**
   * 需要积分大小
   */
  needPointsCount: number
  /**
   * 活动徽章
   */
  badgeId: number
  /**
   * 会员等级(多选)
   */
  memberLevel: any[]
  /**
   * banner地址
   */
  bannerUrl: string
  /**
   * 缩略图地址
   */
  thumbnailUrl: string
  /**
   * 详情页背景图地址
   */
  backgroundUrl: string
  /**
   * 活动介绍
   */
  activityDesc: string
  /**
   * 展示状态
   */
  showStatus: number
  /**
   * 是否首页推荐
   */
  headRecommend: number
  /**
   * 浏览量
   */
  viewCount: number
  createTime: string
  /**
   * 已报名
   */
  ifSingnUp: boolean
  /**
   * 类型补充字段
   */
  studyTravelList?: Schedule[]
  surplus?: number
  studyAllowType?: string
  studyAllowCount?: number
  planStudyEndTime?: string
  planStudyStartTime?: string
  sort?: number
}
export interface StudyTour {
  id: number
  name: string
  studyType: string
  /**
   * 计划报名时间
   */
  planApplyStartTime: number
  planApplyEndTime: number
  /**
   * 计划游学时间
   */
  planStudyStartTime: number
  planStudyEndTime: number
  planStudyAllowType: any
  planStudyAllowCount: any
  studyYear: string
  memberLevel: any
  needPointsType: any
  needPointsCount: any
  badgeId: any
  applyStartTime: any
  applyEndTime: any
  applyStatus: string
  studyStartTime: any
  studyEndTime: any
  studyAllowType: any
  studyAllowCount: any
  bannerUrl: any
  thumbnailUrl: any
  backgroundUrl: any
  studyDesc: any
  isTravelPlan: any
  showStatus: string
  headRecommend: string
  viewCount: any
  createTime: number
  ifSingnUp: boolean
  studyTravelList: Schedule[]
  /**
   * 报名人数
   */
  signUpNumber: number
  /**
   * 剩余名额
   */
  surplus: number
  sort: number
  /**
   * 补充字段
   */
  activityStartTime?: any
  activityEndTime?: any
  activityAddr?: any
  activityAllowType?: string
  activityAllowCount?: number
}
/**
 * 游学/活动的报名信息
 */
export interface ActivitySignUp {
  id: number
  userId: number
  applyTime: number
  applyType: number
  applyStatus: number
  applyPoints: any
  isJoin: string
  createTime: number
  name: string
  headImgUrl: string
  mobile: string
  brokerId: any
  brokerName: string
  memberLevelId: number
  memberLevelName: any
  /**
   * 游学ID
   */
  studyId?: number
  /**
   * 活动ID
   */
  activityId?: number
  avatar?: string
}
export interface MyStudyTour {
  id: number
  name: string
  studyType: string
  planApplyStartTime: number
  planApplyEndTime?: number
  planStudyStartTime: number
  planStudyEndTime?: number
  planStudyAllowType?: string
  planStudyAllowCount?: number
  studyYear: string
  memberLevel: number[]
  needPointsType: string
  needPointsCount?: number
  badgeId?: number
  applyStartTime: number
  applyEndTime: number
  applyStatus?: number
  studyStartTime: number
  studyEndTime: number
  studyAllowType: string
  studyAllowCount: number
  bannerUrl: string
  thumbnailUrl: string
  backgroundUrl: string
  studyDesc: string
  isTravelPlan: number
  showStatus: number
  headRecommend: number
  signUpCount: any
  viewCount: number
  createTime: number
  ifSingnUp: boolean
  studyTravelDOList: {
    createTime: any
    updateTime: any
    creator: any
    updater: any
    deleted: any
    id: any
    studyId: number
    travelDate: any
    travelTime: number
    title: string
    travelDesc: string
    clockExplainDesc: string
    clockExplainUrl: string
  }[]
}

export interface Banner {
  id: number
  name: string
  modeType: BannerMode
  /**
   * 轮播图图片
   */
  bannerImgUrl: string
  /**
   * 轮播图详情类型
   */
  bannerDetailsType: string
  /**
   * 轮播图链接
   */
  bannerLinkUrl: string
  /**
   * 轮播图详情内容
   */
  bannerDetailsContent: any
  /**
   * 状态 - 0: 正常, 1: 停用
   */
  status: number
  /**
   * 浏览量
   */
  viewCount: any
  /**
   * 设计游学年份
   */
  designStudyAbroadYear: any
  /**
   * 设计游学描述
   */
  designDesc: any
  createTime: number
}
export interface Product {
  /* id */
  id: number

  /* 商品名称 */
  prodcutName: string

  /* 商品id */
  productId: string

  /* 商品一级类目 */
  oneCategory: string

  /* 商品一级类目 */
  oneCategoryName: string

  /* 商品二级类目 */
  secondCategory: string

  /* 商品二级类目 */
  secondCategoryName: string

  /* 商品数量是否限制 0:否 1:是 */
  isRestrict: number

  /* 商品市场价 */
  productPrice: string

  /* 商品类别 */
  productType: number

  /* 商品库存 */
  productRepertory: number

  /* 供应商id */
  vendorId: number

  /* 供应商名称 */
  vendorName: string

  /* 供应商状态,可用值:0,1 */
  vendorStatus: string

  /* 是否需要积分 0:否 1:是 */
  needPoints: number

  /* 积分大小 */
  points: number

  /* 获取方式 1:到店核销 3:其他 */
  gainType: number

  /* 兑换说明 */
  exchangeDesc: string

  /* 商品封面地址 */
  productCoverImgUrl: string

  /* 商品详情地址 */
  productDetailsImgUrl: string

  /* 图文详情 */
  contentDesc: string

  /* 状态（0正常 1停用） */
  status: number

  /* */
  statusStr: string

  /* 兑换量 */
  exchangeCount: number

  /* 会员等级ids */
  memberLevelIds: string

  /* 会员等级名称 */
  memberLevelName: string

  /* 超值划算积分 */
  favourablePoints: number

  /* 是否展示超值划算 */
  showFavourable: boolean

  /* 超值划算截止时间 */
  favourableEndDate: Record<string, unknown>

  /* 是否限购 */
  purchaseLimit: boolean

  /* 限购数量 */
  purchaseQuantity: number

  /* 创建时间 */
  createTime: Record<string, unknown>

  /* 更新时间 */
  updateTime: Record<string, unknown>

  /* 排序 */
  sort: number
}
export interface PointsOrder {
  id: number
  orderType: number
  item: number
  materialsId: any
  materialsBrand: any
  stylistId: number
  /**
   * 订单金额
   */
  orderMoney: any
  projectName: string
  pointsRate: any
  /**
   * 积分单价
   */
  points: string
  orderImgUrl: string
  orderStatus: string
  verifyTime: any
  completeTime: number
  turnDownTime: any
  cancelTime: number
  cancelUser?: string
  cancelReason: any
  turnDownReason: any
  remark: any
  couponId: any
  orderNo: string
  createTime: number
  brokerageRate: any
  brokerage: any
  orderQuantity: number
  payType: number
  /**
   * 实付积分
   */
  payPoints: number
  /**
   * 获取方式: 1:到店核销 3:其他
   */
  gainType?: number
}
export interface UserBasicInfo {
  id: number
  userId: number
  avatar: string
  name: string
  sex: number
  birthday: string
  mobile: string
  referrer: string
  brokerName: string
  employer: string
  companyAddress: string
  idCardNumber: string
  passportNumber: string
  householdAddress: string
  cooperationTime: string
  joinTime: string
  circle: string
  hobbies: string
  sharingIntent: number
  createTime: string
  imageNumber: number
  imageUrl: string
  maritalStatus: number
  maritalStatusStr: string
}
export interface UserAuthInfo {
  id: number
  designerName: string
  gender: number
  mobile: string
  channelSource: number
  referrer: string
  employer: string
  spatialExpertiseType: string
  attachment: string
  auditStatus: number
  remark: string
  auditTime: number
}
export interface ResPageData<T> {
  list: T[]
  total: number
}
export interface Message {
  id: number
  title: string
  /**
   * 消息类型
   */
  messageType: number
  /**
   * 消息子类型
   */
  messageSubType: number
  /**
   * 发送会员等级(多个枚举值逗号拼接,选项值包括全部会员等级、普通会员等级、白银会员等级、黄金会员等级、白金会员等级)
   */
  sendMemberGrade: any
  /**
   * 服务号推送状态(0-不推送，1-推送,选项值为推送、不推送选择推送，则该条消息同时会通过公众号推送展示选择不推送，则该条消息不会通过公众号推送),示例值(1)
   */
  serviceNumberStatus: any
  /**
   * 消息内容类型,选项值为创建详情、添加链接,示例值(2)
   */
  messageContentType: any
  /**
   * 添加详情链接,如果消息内容类型为添加链接则该值不为空,示例值(https://www.iocoder.cn)
   */
  linkUrl: string
  /**
   * 封面连接
   */
  coverUrl: string
  /**
   * 图文详情(富文本)
   */
  detailBody: string
  /**
   *  1 已读
   */
  isRead: string
  triggerPort: string
  triggerRole: string
  designerId: number
  businessId: any
  createTime: number
  viewCount: any
  viewTime: any
  pointsDetail?: PointsDetail
}

export interface ConfirmOrder {
  isShoppingCart: number
  userId: number
  list: {
    orderNo: any
    productId: string
    vendorId: number
    productName: string
    points: number
    nums: number
    orderImgUrl: string
  }[]
  couponList: any[]
  totalsPoints: number
  totalsCouponPoints: any
  totalsCurrPoints: any
  item: number
  type: any
}
export enum CouponStatus {
  //   HAVE_USE(1, "已使用"),
  //   NOT_USE(2, "未使用"),
  //   EXPIRED(3, "已过期"),
  //   BECAME_INVALID(4, "已失效"),
  // ;
  HAVE_USE = 1,
  NOT_USE = 2,
  EXPIRED = 3,
  BECAME_INVALID = 4,
}
export interface Coupon {
  id: number
  couponId: number
  userId: number
  sendTime: string
  /**
   * 优惠卷有效开始时间
   */
  validityStartDate: string
  /**
   * 优惠卷有效结束时间
   */
  validityEndDate: string
  /**
   * 是否有效
   */
  isValid: number
  isUse: number
  useTime: string
  /**
   * 材料商id
   */
  material: number
  brandId: number
  buinessId: number
  productId: number
  createTime: string
  brandPoints: number
  couponName: string
  couponType: number
  brandIds: string
  productIds: string
  materialName: string
  couponImgUrl: string
  couponDO?: { couponDesc?: string }
  couponStatus: CouponStatus
}
export interface PointsDetail {
  id: number
  pointsType: string
  typeName: string
  pointsCategory: string
  categoryName: string
  sourceId: any
  name: string
  pointsStauts: number
  points: number
  couponPoints: any
  orderMoney: string
  materialsId: number
  materialsName: any
  materialsBrand: string
  stylistId: number
  brokerId: number
  stylistName: string
  brokerName: string
  generateTime: number
  verifyTime?: number
  completeTime?: number
  turnDownTime: any
  cancelTime: any
  cancelReason: any
  turnDownReason: any
  remark: any
  couponId: any
  orderNo: any
  createTime: number
  businessType: any
  customerName: string
  customerPhone: string
  orderImgUrl: any
  pointsRate: any
  commission: number
  creator: string
  creatorName: any
}
export interface Todo {
  content: string
  id: number
  status: number
  creator: string
  executionTime: string
}
export interface Agent {
  id: number
  brokeId: string
  headImgUrl: string
  brokerName: string
  password: string
  mobile: string
  status: number
  channelType: number
  designersNumber: any
  yearPoints: any
  yearOrders: any
  createTime: number
  inviteCode: string
  inviteCodeUrl: string
  customer: any
  customerName: string
  points: number
}
export interface Designer {
  id: string
  name: string
  avatar: string
  levelName: string
  points: number
  mobile: string
  accessTime: any
  followUp30Days: boolean
  generatePoints60Days: boolean
  expendPoints60Days: boolean
  focus: boolean
  brokerId: number
  /**
   * 0 弱绑定 1 强绑定
   */
  retryStatus?: 0 | 1
}
export interface DesignerBasicInfo {
  id: number
  userId: number
  avatar: string
  name: string
  sex: number
  birthday: string
  mobile: string
  referrer: string
  brokerName: string
  employer: string
  companyAddress: string
  idCardNumber: string
  passportNumber: string
  householdAddress: string
  cooperationTime: string
  joinTime: string
  circle: string
  hobbies: string
  sharingIntent: number
  createTime: string
  imageNumber: number
  imageUrl: string
  maritalStatus: number
  maritalStatusStr: string
}
/**
 * 设计师家庭信息接口
 */
export interface DesignerFamilyInfo {
  id: number
  userId: number

  /**
   * 家庭成员与用户的关系（例如，父母，兄弟姐妹）。
   */
  familyRelation: string

  /**
   * 家庭成员的姓名。
   */
  familyName: string

  /**
   * 家庭成员的性别。
   */
  familySex: string

  /**
   * 家庭成员的出生日期。
   */
  familyBirthday: string

  /**
   * 家庭成员的兴趣爱好。
   */
  familyInterset: string

  /**
   * 家庭成员的职业。
   */
  familyOccupation: string
  createTime: string
}

/**
 * 设计师奖项
 */
export interface DesignerAward {
  id: number
  userId: number
  awardsName: string
  awardsTime: string
  awardsRank: string
  awardsFileUrl: string
  createTime: string
}
export interface DesignerEvent {
  name: string
  applyTime?: string
  userId?: number
  participationDate: string
  id?: number
}
export interface DesignerPointsStatistics {
  /**
   * 剩余积分
   */
  points: number
  /**
   * 积分变动时间
   */
  pointsTime: string
  /**
   * 累计获得积分
   */
  gainPoints: number
  /**
   * 今年获得积分
   */
  gainPointsYear: number
  /**
   * 今年消耗积分
   */
  usePoints: number
  /**
   * 消耗积分
   */
  usePointsYear: number
  /**
   * 累计跟进次数
   */
  followUpCount: number
  /**
   * 今年跟进次数
   */
  followUpYearCount: number
  /**
   * 消耗次数
   */
  usageCount: number
  /**
   * 今年消耗次数
   */
  usageYearCount: number
  /**
   * 累计获得次数
   */
  obtainedCount: number
  /**
   * 今年获得次数
   */
  obtainedYearCount: number
}
export interface DesignerOrderSaleOther {
  id: number
  supplierName: string
  brandName: string
  saleTime: string
  projectName: string
  customerName: string
  customerPhone: string
  orderAmount: number
  createTime: string
  userId: number
}
export interface Broker {
  createTime: string
  updateTime: string
  creator: string
  updater: string
  deleted: boolean
  id: number
  brokeId: string
  inviteCode: string
  inviteCodeUrl: string
  headImgUrl: string
  brokerName: string
  password: string
  mobile: string
  channelType: number
  status: number
  points: number
}
export interface Report {
  createTime: string
  updateTime: string
  creator: string
  updater: string
  deleted: boolean
  id: number
  verifyTime: string
  verifier: number
  status: string
  taskId: number
  brokerId: number
  reason: string
  remark: string
  num: number
}
export interface ReportInfo {
  id: number
  brokerName: string
  stylistId: number
  /**
   * 设计师姓名
   */
  stylistName: string
  arrivalTime: number
  shopName: string
  receptionist: string
  contactNumber: string
  customerName: string
  customerPhoneNumbe: string
  customerAddress: string
  createTime: number
  reviewStatus: number
  auditId: number
  auditName: string
  auditTime: number
  reason: string
}
export interface AgentTask {
  id: number
  bearerId: number
  bearerName: string
  bearerType: string
  name: string
  storeQuantity: number
  completedNum: number
  personalCompletedNum: number
  startTime: string
  endTime: string
  pointsReward: number
  shopIds: string
  shopNames: string
  detail: string
  taskType: string
  finalType: string
  roleType: string
  status: string
  createTime: string
  receive: boolean
  brokerIds: string
  brokerList: Broker[]
  reportList: Report[]
  bearerTypeName: string
  taskTypeName: string
  finalTypeName: string
  roleTypeName: string
  statusName: string
  qrList?: {
    avatar: string
    createTime: number
    id: number
    name: string
    remark: string
  }[]
}
export interface FollowUp {
  id: number
  brokerId: number
  stylistId: number
  stylistName: string
  followTime: string
  followType: string
  remark: string
  address: Address
  imgUrl: string
  isFollowFocus: string
  followStatus: string
}

export interface Address {
  address: string
  longitude: string
  latitude: string
}
export interface AgentPoint {
  id: number
  bizId: number
  bizType: string
  sourceId: number
  sourceType: number
  targetId: number
  taskName: string
  targetType: string
  points: number
  remark: string
  createTime: string
}
export interface BrowseRecord {
  /* */
  createTime: Record<string, unknown>

  /* */
  updateTime: Record<string, unknown>

  /* */
  creator: string

  /* */
  updater: string

  /* */
  deleted: boolean

  /* id */
  id: number

  /* 设计师id */
  stylistId: number

  /* 设计师名称 */
  stylistName: string

  /* 业务id */
  bizId: string

  /* 业务类型：分享-1，获客-2，浏览-3等具体查看BrowseTypeEnum类,可用值:1,2,3,4,5 */
  bizType: string

  /* 分享类型,可用值:1,2 */
  shareType: string

  /* 时长：单位-秒 */
  duration: string

  /* 创建人 */
  creatorName: string

  /* 备注 */
  remark: string
}
/**
 * 设计师动态统计
 */
export interface BrowseRecordCountRes {
  /* 打开次数 */
  openNumber: number

  /* 最近打开时间 */
  openTime: string

  /* 浏览时间 */
  duration: number

  /* 本年浏览时间 */
  durationYear: number

  /* 发圈次数 */
  circleNumber: number

  /* 本年发圈次数 */
  circleNumberYear: number

  /* 主页分享 */
  homeShareNumber: number

  /* 本年分享 */
  homeShareNumberYear: number

  /* 分享浏览数 */
  shareViewNumber: number

  /* 本年分享浏览数 */
  shareViewNumberYear: number

  /* 分享获客数 */
  customersAcquired: number

  /* 本年分享获客数 */
  customersAcquiredYear: number
}

export enum DictType {
  /**
   *  擅长空间类型
   */
  memberSpatialExpertiseType = 'member_spatial_expertise_type',
  /**
   * 设计风格
   */
  memberDesignStyle = 'member_design_style_type',
  /**
   * 空间类型
   */
  circleSpaceType = 'member_circle_space_type',
  /**
   * 圈子标签
   */
  circleTag = 'basic_set_label_type',
  /**
   * 材料商品牌等级
   */
  memberMaterialsBrandLevel = 'member_materials_brand_level',
  /**
   * 材料商运营类型
   */
  memberMaterialsOperationType = 'member_materials_operation_type',
  /**
   * 内容分类-线下活动
   */
  offlineActivity = 'offline_activity',
  /**
   * 材料商-品牌-类型
   */
  memberMaterialsBrandType = 'member_materials_brand_type',
  /**
   * 材料商-经营-品牌
   */
  materialsManageBrand = 'member_materials_manage_brand',
  /**
   * 活动类型
   */
  MemberActivityType = 'member_activity_type',
}
/**
 * 徽章
 */
export interface Badge {
  id: number
  userId: number
  quantity: number
  badgeId: number
  badgeType: string
  badgeName: string
  badgeNotObtainedImage: string
  badgeYesObtainedImage: string
  badgeDescription: string
  popUp: boolean
}
/**
 * 证书
 */
export interface Certificate {
  id: number
  userId: number
  certificateId: number
  certificateName: string
  studyName: string
  certificateImage: string
  certificateDescription: string
  createTime: string
  popUp: boolean
}
export enum CircleType {
  moment = '1',
  case = '2',
}
export enum BannerMode {
  /**
   * 材料商
   */
  Material = 1,
  /**
   * 设计传播
   */
  Spread = 2,
  /**
   * 品质商城
   */
  Mall = 3,
  /**
   * 设计奖项
   */
  DesignAwards = 4,
  /**
   * 设计游学
   */
  StudyTour = 5,
}
